@echo off
setlocal

REM *************************************************************************
REM
REM Licensed Materials - Property of IBM
REM
REM 5724-CYN
REM
REM (C) Copyright IBM Corp. 2005  All Rights Reserved.
REM
REM US Government Users Restricted Rights - Use, duplication or
REM disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
REM
REM *************************************************************************
REM @(#)48   1.9   ppe.probe/src/bin/cyn_collector.cmd, am_ppe.probe, itcam61, 20061116A 10/24/06 15:33:44
REM *************************************************************************

REM The DC installer sets this variable to the DC runtime path
set PROD_HOME="@{AM_HOME}"

REM The DC installer sets this variable to the Tivoli common directory path
set COMDIR="@{TIVOLI_COMMON_DIR}"

REM The DC installer sets this variable to the Java runtime path
set JAVA_HOME="@{JAVA_HOME}"

if x%1==x goto start

if %1==-help goto help else (
  echo.
  echo Error: unknown option  %1
  echo.
  goto end
)

:start

echo Data Collector runtime located in %PROD_HOME%

if not exist %PROD_HOME% (
echo Error: %PROD_HOME% does not exist
goto end
)

chdir /d %PROD_HOME%

set TMPDIR="%TEMP%\CYN"
set DESTNAME=%COMPUTERNAME%-CYNenv
set DESTDIR=%TMPDIR%\%DESTNAME%
set JAR=%JAVA_HOME%\bin\java.exe sun.tools.jar.Main
set JAVA=%JAVA_HOME%\bin\java.exe
set TOOLKIT=%PROD_HOME%\..\toolkit

set CLASSPATH=%TOOLKIT%\lib\bcm-bootstrap.jar;%TOOLKIT%\lib\ext\cdn.jar;%TOOLKIT%\lib\ext\jffdc.jar;%TOOLKIT%\lib\ext\jflt.jar;%TOOLKIT%\lib\ext\jlog.jar;%TOOLKIT%\lib\ext\tk_jflt.jar;%TOOLKIT%\lib\ext\aspectjrt.jar

if exist %DESTDIR% rd /s /q %DESTDIR%
if exist %DESTDIR%.jar del /f /q %DESTDIR%.jar
md %DESTDIR%

echo Collecting environment information ...
dir /s > %DESTDIR%\dir.info
set > %DESTDIR%\env.info

if exist "%SYSTEMROOT%"\system32\systeminfo.exe (
echo Collecting system information ...
"%SYSTEMROOT%"\system32\systeminfo.exe > %DESTDIR%\system.info
)

if exist "%SYSTEMROOT%"\system32\fsutil.exe (
echo Collecting disk space information ...
echo Space on the system drive %SYSTEMDRIVE% > %DESTDIR%\disk.info
"%SYSTEMROOT%"\system32\fsutil.exe volume diskfree %SYSTEMDRIVE% >> %DESTDIR%\disk.info
echo. >> %DESTDIR%\disk.info
echo Space on the drive where the product resides: >> %DESTDIR%\disk.info
"%SYSTEMROOT%"\system32\fsutil.exe volume diskfree %PROD_HOME% >> %DESTDIR%\disk.info
)

echo Collecting network information ...
ipconfig /all > %DESTDIR%\ipconfig.info
netstat /a /n > %DESTDIR%\netstat.info
if exist "%SYSTEMROOT%"\system32\netsh.exe (
netsh diag show all > %DESTDIR%\netsh.info
)

echo Collecting registry information ...
regedit /e %DESTDIR%\userenv.reg HKEY_CURRENT_USER\Environment
regedit /e %DESTDIR%\sysenv.reg "HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\Session Manager\Environment"
regedit /e %DESTDIR%\candle.reg HKEY_LOCAL_MACHINE\SOFTWARE\Candle
regedit /e %DESTDIR%\ibm.reg HKEY_LOCAL_MACHINE\SOFTWARE\IBM

echo Collecting log files ...
if exist %COMDIR%\BWM\logs xcopy %COMDIR%\BWM\logs %DESTDIR%\common\BWM\logs /y /q /s /i /r >nul
if exist %COMDIR%\BWM\FFDC xcopy %COMDIR%\BWM\FFDC %DESTDIR%\common\BWM\FFDC /y /q /s /i /r >nul
if exist %COMDIR%\CYN\logs xcopy %COMDIR%\CYN\logs %DESTDIR%\common\CYN\logs /y /q /s /i /r >nul
if exist %COMDIR%\CYN\FFDC xcopy %COMDIR%\CYN\FFDC %DESTDIR%\common\CYN\FFDC /y /q /s /i /r >nul
if exist "%USERPROFILE%\My Documents"\DB2LOG\db2.log copy /y "%USERPROFILE%\My Documents"\DB2LOG\db2.log %DESTDIR%\db2.log >nul
xcopy logs %DESTDIR%\logs /y /q /s /i /r >nul

echo Collecting configuration files ...
xcopy etc %DESTDIR%\etc /y /q /s /i /r >nul
xcopy ..\runtime %DESTDIR%\runtime /y /q /s /i /r >nul

if exist "%SYSTEMROOT%"\system32\eventquery.vbs (
echo Collecting errors and warnings from the event log ...
cscript "%SYSTEMROOT%"\system32\eventquery.vbs //nologo /fi "Type eq Error or Type eq Warning" /v > %DESTDIR%\events.info
)

echo Collecting maintenance levels for all classes
%JAVA% -cp %CLASSPATH% com.ibm.tivoli.itcam.toolkit.ai.scanner.ClassScanner -classpath %PROD_HOME%\.. >%DESTDIR%\classmaint.log 2>nul

echo Packing collected data ...
%JAR% -cMf %DESTDIR%.jar -C %TMPDIR% %DESTNAME%
rd /s /q %DESTDIR%

echo.
echo ********************************************************************
echo %DESTDIR%.jar
echo This file has been created and contains diagnostic information.
echo Forward this binary file to your IBM Support representative.
echo ********************************************************************
echo.

goto end:

:help
echo.
echo     %~n0%~x0	Version 06.00.00
echo.
echo.
echo This program is intended to collect diagnostic information from the
echo computer upon which it is executed. Collected data includes:
echo     - system configuration;
echo     - environment;
echo     - disk space information;
echo     - network state;
echo     - errors and warnings from the event log;
echo     - Data Collector configuration and log files.
echo.
echo.
echo Command line syntax is:
echo.
echo    %~n0%~x0
echo.

:end
