#!/bin/sh
#
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2005, 2006  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# @(#)56   1.4   ppe.proxy/src/bin/proxyserverctrl_j2ee.sh, am_ppe.proxy, itcam61, 20061116A 11/11/06 00:43:53
#
# (c) 2002-2004 Cyanea Systems Corp.
# All Rights Reserved

find_procs() 
{
  OS=`uname`
  case $OS in 
    Linux )
    PID_CMD="ps -auxww | grep '$1 start' | grep $2 | grep -v grep ";
  ;;
    AIX)
    PID_CMD="( export COLUMNS=5000 ; ps -eaf | grep '$1 start' | grep $2 | grep -v grep )";
  ;;
    SunOS )
    PID_CMD="/usr/ucb/ps -auxww | grep '$1 start' | grep $2 | grep -v grep ";
  ;;
  esac

  FIND_PID=`eval ${PID_CMD} | awk '{ print $2 }'`
  export FIND_PID
}

usage()
{
        echo "usage: ./$1 ( start | stop | forcestop | killall | ping | list | delete | msg | trace)";
        echo "  start      - start port consolidator";
        echo "  stop       - stop port consolidator";
        echo "  forcestop  - kill -9 all port consolidator proccesses";
        echo "  ping       - ping port consolidator";
        echo "  list       - list all registered datacollectors";
        echo "  delete     - delete all registered datacollectors";
        echo "  msg logLevel   - change log level for msg logger";
	echo "  trace logLevel - change log level for trace logger";
	echo "  where logLevel is [ error | warn | info | debug_min | debug_mid | debug_max]";
}

##########    Set environment variables  ################################
# it's required to setting up the following environment variables before#
# starting the port consolidator                                        #
#########################################################################
cmdName=`basename ${0}`

JAVA_HOME=@{JAVA_HOME}
TK_HOME=@{TOOLKITHOME}
AM_HOME=@{AM_HOME}
AM_MS_HOME="@{MS_AM_HOME}"
# RG: updated am version
AM_VERSION=@{AM_VERSION}
#APPSERVER_VERSION=@{APPSERVER_VERSION}
PROXY_PORT=8800
KERNEL_HOST01=@{KERNEL_HOST01}
# RG:commented out this kernel and codebase
#KERNEL_HOST02=@{KERNEL_HOST02}
PORT_KERNEL_CODEBASE01=@{PORT_KERNEL_CODEBASE01}
#PORT_KERNEL_CODEBASE02=@{PORT_KERNEL_CODEBASE02}
#PORT_KERNEL_RFS01=@{PORT_KERNEL_RFS01}
#PORT_KERNEL_RFS02=@{PORT_KERNEL_RFS02}
CODEBASE_ADDRESS01=$KERNEL_HOST01:$PORT_KERNEL_CODEBASE01
#CODEBASE_ADDRESS02=$KERNEL_HOST02:$PORT_KERNEL_CODEBASE02

COMMAND=$1

LOGS_HOME=/var/ibm/tivoli/common/CYN/logs

if [ ! -d "${LOGS_HOME}" ]; then
    LOGS_HOME=${AM_HOME}
fi

if [ ! -d ${JAVA_HOME}/bin ]; then
  if [ -d @{JAVA_HOME}/bin ]; then
    JAVA_HOME="@{JAVA_HOME}"
  else
     echo " The JDK cannot be found at ${JAVA_HOME} "
     echo " Please set JAVA_HOME in proxyserverctrl_ws.sh"
     exit 1
  fi
fi

#This doesn't work on Solaris
#APPSERVER_MAJOR_VERSION=`expr substr ${APPSERVER_VERSION} 1 1`

#APPSERVER_MAJOR_VERSION=`echo ${APPSERVER_VERSION} |sed -e 's/\(.\).*/\1/'`
#APPSERVER_MAJOR_VERSION=`echo ${APPSERVER_VERSION} | cut -c 1`
#echo "Application server major version is ${APPSERVER_MAJOR_VERSION}"

temp=`echo ${AM_MS_HOME} | cut -c 1`
if [ "$temp" = "/" ] ; then
  SEPERATOR=//
  echo "MS is on UNIX"
else
  SEPERATOR=/
  echo "MS is on WINDOWS"
fi

#substitute space with %20 
AM_MS_HOME=`echo ${AM_MS_HOME} | sed -e 's/ /%20/g'`
echo "MS_HOME=${AM_MS_HOME}"

#if [ "$COMMAND" = "" ] ; then
#  COMMAND=ping
#fi

#PROXY_PROPERTIES=proxy.properties

if [ "$LOG_PROPERTIES" = "" ] ; then
  LOG_PROPERTIES=cynlogging.properties
fi

if [ "$AM_VERSION" = "" ] ; then
  AM_VERSION=6.1
fi

if [ "$AM_VERSION" = "@{AM_VERSION}" ] ; then
  AM_VERSION=6.1
fi

echo "AM_VERSION is $AM_VERSION"

# RG:
if [  -d "${LOGS_HOME}/j2eeproxy" ]; then
  echo "Directory ${LOGS_HOME}/j2eeproxy already present"
else
  echo "Creating directory for j2eeproxy"
  mkdir ${LOGS_HOME}/j2eeproxy
fi

case $COMMAND in
    start) 
        find_procs com.cyanea.proxy.Server "proxy.rmi.port=${PROXY_PORT}"
        if [ "$FIND_PID" != "" ] ; then
            echo "Proxy Server has already been started on this machine ";
            exit 1;
        fi
        echo "starting port consolidator..."
        CLASSPATH=.
        CLASSPATH=${CLASSPATH}:${AM_HOME}/lib/ext/common.jar
        CLASSPATH=${CLASSPATH}:${AM_HOME}/lib/ext/cyaneaaux.jar
        CLASSPATH=${CLASSPATH}:${AM_HOME}/lib/ext/model.jar
        CLASSPATH=${CLASSPATH}:${AM_HOME}/lib/ext/ppe.proxy-intf.jar
        CLASSPATH=${CLASSPATH}:${AM_HOME}/lib/ext/ppe.probe-intf.jar
        CLASSPATH=${CLASSPATH}:${AM_HOME}/lib/ext/ppe.probe.jar
        CLASSPATH=${CLASSPATH}:${AM_HOME}/lib/ext/kernel.common.jar
        CLASSPATH=${CLASSPATH}:${AM_HOME}/lib/ext/ppe.proxy.jar
        CLASSPATH=${CLASSPATH}:${TK_HOME}/lib/ext/tk_jflt.jar
       
        SECURITY_POLICY_PROXY=${AM_HOME}/etc/proxy.policy

	RMI_CODEBASE="file:${SEPERATOR}${AM_MS_HOME}/lib/ppe.proxy-intf.jar file:${SEPERATOR}${AM_MS_HOME}/lib/ppe.probe-intf.jar file:${SEPERATOR}${AM_MS_HOME}/lib${AM_VERSION}/ppe.proxy.jar  file:${SEPERATOR}${AM_MS_HOME}/lib${AM_VERSION}/ppe.probe.jar file:${SEPERATOR}${AM_MS_HOME}/lib${AM_VERSION}/ppe.probe-bootstrap.jar"
	echo ${RMI_CODEBASE}
        if [ "$HEAP_MIN_SIZE" = "" ] ; then
	   HEAP_MIN_SIZE=64
        fi
        if [ "$HEAP_MAX_SIZE" = "" ] ; then
	   HEAP_MAX_SIZE=64
        fi

	${JAVA_HOME}/bin/java -classpath $CLASSPATH \
	    -Dam.home=${AM_HOME} \
            -Dproxy.rmi.port=${PROXY_PORT} \
            -Djava.security.policy=${SECURITY_POLICY_PROXY} \
            -Dkernel.codebase="http://$CODEBASE_ADDRESS01/kernel.core.jar " \
	    -Dkernel.rfs.address="" \
            -Djava.rmi.server.codebase="${RMI_CODEBASE}" \
	    -Djlog.propertyFileDir.CYN="${TK_HOME}/etc" \
	    -Dcom.ibm.tivoli.itcam.toolkit.util.logging.qualDir="j2eeproxy" \
            -Xms${HEAP_MIN_SIZE}m \
            -Xmx${HEAP_MAX_SIZE}m \
            com.cyanea.proxy.Server $@ 2>>${LOGS_HOME}/am_stderr.log | tee -a ${LOGS_HOME}/am_stdout.log &
    ;;
    
    stop | ping | list | delete | msg | trace)
        echo "contacting port consolidator";
        CLASSPATH=${CLASSPATH}:${AM_HOME}/lib/ext/common.jar
        CLASSPATH=${CLASSPATH}:${AM_HOME}/lib/ext/cyaneaaux.jar
        CLASSPATH=${CLASSPATH}:${AM_HOME}/lib/ext/model.jar
        CLASSPATH=${CLASSPATH}:${AM_HOME}/lib/ext/kernel.common.jar
        CLASSPATH=${CLASSPATH}:${AM_HOME}/lib/ext/ppe.proxy-intf.jar
        CLASSPATH=${CLASSPATH}:${AM_HOME}/lib/ext/ppe.probe-intf.jar
        CLASSPATH=${CLASSPATH}:${AM_HOME}/lib/ext/ppe.proxy.jar
        CLASSPATH=${CLASSPATH}:${TK_HOME}/lib/ext/tk_jflt.jar

        SECURITY_POLICY_PROXY=${AM_HOME}/etc/proxy.policy
        LOGLEVEL=""
        if [ "$COMMAND" = "msg" ] || [ "$COMMAND" = "trace" ]; then
            argc=$#
            if [ "$argc" = 1 ]; then
	        echo "logLevel is not specified"
                usage $cmdName
                exit 1
            else
                case $2 in 
                debug_max)
                    LOGLEVEL=1
                    ;;
                debug_mid)
                    LOGLEVEL=2
                    ;;
                debug_min)
                    LOGLEVEL=3
                    ;;
                info)
                    LOGLEVEL=4
                    ;;
                warn)
                    LOGLEVEL=5
                    ;;
                error)
                    LOGLEVEL=6
                    ;;
                *)
                    usage &cmdName
                    exit 1
                    ;;
                esac
             fi
        fi
        ${JAVA_HOME}/bin/java -classpath $CLASSPATH \
            -Dproxy.rmi.port=${PROXY_PORT} \
            -Djava.security.policy=${SECURITY_POLICY_PROXY} \
            -Dkernel.codebase="http://$CODEBASE_ADDRESS01/kernel.core.jar " \
	    -Dkernel.rfs.address="" \
	    -Djlog.propertyFileDir.CYN="${TK_HOME}/etc" \
	    -Dcom.ibm.tivoli.itcam.toolkit.util.logging.qualDir="j2eeproxy" \
            -Dam.home=${AM_HOME} \
            com.cyanea.proxy.Server $COMMAND $LOGLEVEL;
    ;;    
    killall | forcestop ) 
        find_procs com.cyanea.proxy.Server com.cyanea.proxy.Server
        if [ "$FIND_PID" = "" ] ; then
            echo "port consolidator does not appear to be running, (no processes found)."
            exit 1;
        fi;
        kill -9  $FIND_PID;
    ;;
    *) 
      usage $cmdName
    ;;
esac

